==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Clear log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Refresh</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Are you sure you want to clear the log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 days</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 week</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 month</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 months</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Export</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergency</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critical</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notice</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Shutdown</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critical</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exporting...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Export successful</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export failed</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Export File</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Period:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Level:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Application list:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Event Type:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>User:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Username:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Boot record</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Shutdown record</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Login record</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergency</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critical</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notice</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critical</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Log file is empty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Log Viewer</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer is a useful tool for viewing system logs.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Process</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Date and Time</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Event Type</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Process:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Date and Time:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>User:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Date and Time</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>System Log</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel Log</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot Log</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg Log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin Log</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Application Log</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Boot-Shutdown Event</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf Log</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Clear log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Refresh</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Are you sure you want to clear the log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 days</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 week</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 month</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 months</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergency</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critical</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notice</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Shutdown</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critical</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exporting...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Export successful</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export failed</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Export File</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Period:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Level:  </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Event Type:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>User:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Username:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Boot record</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Shutdown record</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Login record</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Audit Type:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Application:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Submodule:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergency</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critical</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notice</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super critical</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Log file is empty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Log Viewer</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer is a useful tool for viewing system logs.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Process</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Date and Time</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Event Type</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Process:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Date and Time:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>User:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>File Name</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Time Modified</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Date and Time</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>System Log</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel Log</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot Log</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg Log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin Log</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Application Log</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Boot-Shutdown Event</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf Log</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Other Log</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Custom Log</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>You do not have permission to view it</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Refresh interval</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sec</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>No refresh</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Export All</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Refresh Now</translation>
    </message>
</context>
</TS>
